@@ -1,7 +1,9 @@
 package Sah::Schema::cryptocurrency;
 
-our $DATE = '2019-11-29'; # DATE
-our $VERSION = '0.013'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-04'; # DATE
+our $DIST = 'Sah-Schemas-CryptoCurrency'; # DIST
+our $VERSION = '0.014'; # VERSION
 
 our $schema = [str => {
     summary => 'Cryptocurrency code, name, or safename',
@@ -17,6 +19,13 @@ Will be normalized to code in uppercase.
 _
     'x.completion' => 'cryptocurrency',
     'x.perl.coerce_rules' => ['From_str::to_cryptocurrency_code'],
+    examples => [
+        {value=>'', valid=>0},
+        {value=>'btc', valid=>1, validated_value=>'BTC'},
+        {value=>'bitcoin', valid=>1, validated_value=>'BTC'},
+        {value=>'bitCOIN caSh', valid=>1, validated_value=>'BCH'},
+        {value=>'notbtc', valid=>0},
+    ],
 }, {}];
 
 1;
@@ -34,7 +43,51 @@ Sah::Schema::cryptocurrency - Cryptocurrency code, name, or safename
 
 =head1 VERSION
 
-This document describes version 0.013 of Sah::Schema::cryptocurrency (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2019-11-29.
+This document describes version 0.014 of Sah::Schema::cryptocurrency (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2020-03-04.
+
+=head1 SYNOPSIS
+
+Using with L<Data::Sah>:
+
+ use Data::Sah qw(gen_validator);
+ my $vdr = gen_validator("cryptocurrency*");
+ say $vdr->($data) ? "valid" : "INVALID!";
+
+ # Data::Sah can also create a validator to return error message, coerced value,
+ # even validators in other languages like JavaScript, from the same schema.
+ # See its documentation for more details.
+
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+
+ package MyApp;
+ our %SPEC;
+ $SPEC{myfunc} = {
+     v => 1.1,
+     summary => 'Routine to do blah ...',
+     args => {
+         arg1 => {
+             summary => 'The blah blah argument',
+             schema => ['cryptocurrency*'],
+         },
+         ...
+     },
+ };
+ sub myfunc {
+     my %args = @_;
+     ...
+ }
+
+Sample data:
+
+ undef  # INVALID
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # INVALID
 
 =head1 DESCRIPTION
 
@@ -67,7 +120,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
