@@ -1,7 +1,9 @@
 package Sah::Schema::cryptoexchange::safename;
 
-our $DATE = '2019-11-29'; # DATE
-our $VERSION = '0.013'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-04'; # DATE
+our $DIST = 'Sah-Schemas-CryptoCurrency'; # DIST
+our $VERSION = '0.014'; # VERSION
 
 our $schema = [str => {
     summary => 'Cryptocurrency exchange safename',
@@ -24,7 +26,39 @@ Sah::Schema::cryptoexchange::safename - Cryptocurrency exchange safename
 
 =head1 VERSION
 
-This document describes version 0.013 of Sah::Schema::cryptoexchange::safename (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2019-11-29.
+This document describes version 0.014 of Sah::Schema::cryptoexchange::safename (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2020-03-04.
+
+=head1 SYNOPSIS
+
+Using with L<Data::Sah>:
+
+ use Data::Sah qw(gen_validator);
+ my $vdr = gen_validator("cryptoexchange::safename*");
+ say $vdr->($data) ? "valid" : "INVALID!";
+
+ # Data::Sah can also create a validator to return error message, coerced value,
+ # even validators in other languages like JavaScript, from the same schema.
+ # See its documentation for more details.
+
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+
+ package MyApp;
+ our %SPEC;
+ $SPEC{myfunc} = {
+     v => 1.1,
+     summary => 'Routine to do blah ...',
+     args => {
+         arg1 => {
+             summary => 'The blah blah argument',
+             schema => ['cryptoexchange::safename*'],
+         },
+         ...
+     },
+ };
+ sub myfunc {
+     my %args = @_;
+     ...
+ }
 
 =head1 HOMEPAGE
 
@@ -48,7 +82,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
