@@ -1,7 +1,9 @@
 package Sah::Schemas::CryptoCurrency;
 
-our $DATE = '2019-11-29'; # DATE
-our $VERSION = '0.013'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-04'; # DATE
+our $DIST = 'Sah-Schemas-CryptoCurrency'; # DIST
+our $VERSION = '0.014'; # VERSION
 
 1;
 # ABSTRACT: Various Sah cryptocurrency schemas
@@ -18,7 +20,7 @@ Sah::Schemas::CryptoCurrency - Various Sah cryptocurrency schemas
 
 =head1 VERSION
 
-This document describes version 0.013 of Sah::Schemas::CryptoCurrency (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2019-11-29.
+This document describes version 0.014 of Sah::Schemas::CryptoCurrency (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2020-03-04.
 
 =head1 SAH SCHEMAS
 
@@ -96,7 +98,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
